@@ -19,6 +19,7 @@
 
 import aeidon
 import os
+import shutil
 import sys
 
 from aeidon.i18n import _
@@ -159,6 +160,8 @@ class PlayerMPlayer(aeidon.EnumerationItem):
         # http://www.mplayerhq.hu/DOCS/HTML/en/faq.html#idm5930
         command_utf_8 = "{} < /dev/null".format(command_utf_8)
 
+    executable = _get_mplayer_executable()
+    found = shutil.which(_get_mplayer_executable()) is not None
     label = "MPlayer"
 
 class PlayerMPV(aeidon.EnumerationItem):
@@ -179,6 +182,8 @@ class PlayerMPV(aeidon.EnumerationItem):
                               "--sub-codepage=utf-8",
                               "$VIDEOFILE",))
 
+    executable = _get_mpv_executable()
+    found = shutil.which(_get_mpv_executable()) is not None
     label = "mpv"
 
 class PlayerVLC(aeidon.EnumerationItem):
@@ -193,6 +198,8 @@ class PlayerVLC(aeidon.EnumerationItem):
                               ":sub-file=$SUBFILE",
                               ":subsdec-encoding=UTF-8",))
 
+    executable = _get_vlc_executable()
+    found = shutil.which(_get_vlc_executable()) is not None
     label = "VLC"
 
 players = aeidon.Enumeration()
